pub fn parse_pact_file(
path: impl AsRef<Path>,
) -> Result<PactInterface, PactFileError>Expand description
Parse a single .pact file from disk.
The interface name will be derived from the filename (without .pact extension).
pub fn parse_pact_file(
path: impl AsRef<Path>,
) -> Result<PactInterface, PactFileError>Parse a single .pact file from disk.
The interface name will be derived from the filename (without .pact extension).