pub struct BuiltComposition { /* private fields */ }Expand description
A built composition ready for execution.
Implementations
Sourceimpl BuiltComposition
impl BuiltComposition
Sourcepub fn call(
&mut self,
package: &str,
function: &str,
input: &Value,
) -> Result<Value, RuntimeError>
pub fn call( &mut self, package: &str, function: &str, input: &Value, ) -> Result<Value, RuntimeError>
Call a function on a package in the composition.
Sourcepub fn types(&mut self, package: &str) -> Result<PackageMetadata, MetadataError>
pub fn types(&mut self, package: &str) -> Result<PackageMetadata, MetadataError>
Read embedded type metadata from a package in the composition.
Returns Err(MetadataError::NotFound) if the package doesn’t exist
or doesn’t export __pack_types.