ErrorHandler

Type Alias ErrorHandler 

pub type ErrorHandler = Arc<dyn Fn(&HostFunctionError) + Send + Sync>;
Handler function for host function errors.

This is called whenever an error occurs in a typed host function, allowing for logging, metrics, or other error handling.

Aliased Type

pub struct ErrorHandler { /* private fields */ }