pub enum Type {
}Expand description
A type reference.
This enum represents all possible types in the Pack type system. Types can be primitive, compound, or references to named types.
Variants
Unit
Bool
U8
U16
U32
U64
S8
S16
S32
S64
F32
F64
Char
String
List(Box<Type>)
Option(Box<Type>)
Result
Tuple(Vec<Type>)
Ref(TypePath)
Value
Implementations
Sourceimpl Type
impl Type
Sourcepub fn named(name: impl Into<String>) -> Self
pub fn named(name: impl Into<String>) -> Self
Create a reference to a named type by simple name.
Sourcepub fn self_ref() -> Self
pub fn self_ref() -> Self
Create a self-reference (reference to the containing type). This is syntactic sugar for a relative path with no segments.
Sourcepub fn is_self_ref(&self) -> bool
pub fn is_self_ref(&self) -> bool
Check if this type is a self-reference.
Sourcepub fn contains_recursion(&self) -> bool
pub fn contains_recursion(&self) -> bool
Check if this type contains any recursive references.