Package Runtime
Handles package instantiation, linking, and execution.
Re-exports
pub use interceptor::CallInterceptor;
Modules
- interceptor
- Call Interceptor
Structs
- Async
Compiled Module - A compiled WASM module for async execution.
- Async
Ctx - Async context for async host functions.
- Async
Instance - An async WASM instance.
- Async
Runtime - An async-enabled package runtime.
- Built
Composition - A built composition ready for execution.
- Compiled
Module - A compiled WASM module, ready to be instantiated
- Composition
Builder - Builder for creating composed packages with cross-package imports.
- Ctx
- Context wrapper providing ergonomic access to store data and memory.
- Default
Host Provider - Default host function provider for backward compatibility.
- Engine
- An
Enginewhich is a global context for compilation and management of wasm modules. - Host
Function Error - Error that occurred during host function execution.
- Host
Imports - Builder for configuring host imports
- Host
Linker Builder - Builder for registering host functions with a Linker.
- Host
State - State accessible to host functions
- Instance
- A running WASM instance
- Instance
With Host - Instance with host imports - provides access to host state
- Interface
Builder - Builder for registering functions within a specific interface/namespace.
- Module
- A compiled WebAssembly module, ready to be instantiated.
- Runtime
- The package runtime
Enums
- Expected
Signature - The expected WASM signature for Graph ABI functions
- Host
Function Error Kind - The specific kind of error that occurred in a host function.
- Interface
Error - Errors from interface validation
- Linker
Error - Errors from linker operations
- Runtime
Error
Constants
- INPUT_
BUFFER_ OFFSET - Default input buffer offset (0-16KB)
- OUTPUT_
BUFFER_ CAPACITY - Default output buffer capacity (32KB) - DEPRECATED: guest now allocates
- OUTPUT_
BUFFER_ OFFSET - Default output buffer offset (16KB) - DEPRECATED: use RESULT_PTR_OFFSET
- RESULT_
LEN_ OFFSET - Offset for result length slot (4 bytes at 16KB + 4) Used by new guest-allocates ABI: guest writes output len here
- RESULT_
PTR_ OFFSET - Offset for result pointer slot (4 bytes at 16KB) Used by new guest-allocates ABI: guest writes output ptr here
Traits
- Host
Function Provider - Trait for types that provide host functions.
Functions
- validate_
instance_ implements_ interface - Validate that a WASM instance implements all functions required by an interface
Type Aliases
- Async
Host FnResult - Type alias for async host function return type.
- Error
Handler - Handler function for host function errors.
- HostFn
- A host function that can be wired into compositions.